@@ -4,21 +4,13 @@
 if (!isGeneric("expand"))
     setGeneric("expand", function(x, ...) standardGeneric("expand"))
 
-## if (!isGeneric("tcrossprod"))
-##   setGeneric("tcrossprod", function(x, y = NULL) standardGeneric("tcrossprod"))
-if (!exists("tcrossprod"))# R <= 2.2.x :
-    tcrossprod <- function(x, y = NULL) x %*% t(if(is.null(y)) x else y)
-## will become generic by setMethod(..)
+## tcrossprod() is now in R's base
 
 if (!isGeneric("isDiagonal"))
     setGeneric("isDiagonal", function(object, ...)
                standardGeneric("isDiagonal"))
 
-if (!isGeneric("isSymmetric"))
-    ## no "..." here at the moment; must match isSymmetric()
-    ## R 2.3.x base/R/eigen.R
-    setGeneric("isSymmetric", function(object, ...)# no 'tol' in generic
-	       standardGeneric("isSymmetric"))
+## isSymmetric is "S3 generic" in R's  base/R/eigen.R
 
 if (!isGeneric("isTriangular"))
     setGeneric("isTriangular", function(object, ...) ## 'upper = NA'
@@ -151,8 +143,8 @@ if (!isGeneric("getFixDF")) {           # not exported
 }
 
 if (!isGeneric("mcmcsamp")) {
-    setGeneric("mcmcsamp", function(object, n = 1, verbose =
-    FALSE, ...) standardGeneric("mcmcsamp"))
+    setGeneric("mcmcsamp", function(object, n = 1, verbose = FALSE, ...)
+	       standardGeneric("mcmcsamp"))
 }
 
 if (!exists("simulate", mode = "function")) {
