@@ -1,3 +1,3 @@
 setMethod("expand", signature(x = "LU"),
           function(x, ...)
-          .Call("LU_expand", x, PACKAGE = "Matrix"))
+          .Call(LU_expand, x))
