@@ -1,7 +1,7 @@
 #### Triangular Packed Matrices -- Coercion and Methods
 
 setAs("dtpMatrix", "dtrMatrix",
-      function(from) .Call("dtpMatrix_as_dtrMatrix", from, PACKAGE = "Matrix"))
+      function(from) .Call(dtpMatrix_as_dtrMatrix, from))
 
 setAs("dtpMatrix", "dgeMatrix",
       function(from) as(as(from, "dtrMatrix"), "dgeMatrix"))
@@ -23,9 +23,9 @@ setAs("matrix", "dtpMatrix",
 
 
 setMethod("%*%", signature(x = "dtpMatrix", y = "dgeMatrix"),
-	  function(x, y) .Call("dtpMatrix_dgeMatrix_mm", x, y, PACKAGE = "Matrix"))
+	  function(x, y) .Call(dtpMatrix_dgeMatrix_mm, x, y))
 setMethod("%*%", signature(x = "dgeMatrix", y = "dtpMatrix"),
-	  function(x, y) .Call("dgeMatrix_dtpMatrix_mm", x, y, PACKAGE = "Matrix"))
+	  function(x, y) .Call(dgeMatrix_dtpMatrix_mm, x, y))
 ## %*% should always work for  <fooMatrix> %*% <fooMatrix>
 setMethod("%*%", signature(x = "dtpMatrix", y = "dtpMatrix"),
           function(x, y)
@@ -66,37 +66,37 @@ setMethod("determinant", signature(x = "dtpMatrix", logarithm = "logical"),
 	  })
 
 setMethod("diag", signature(x = "dtpMatrix"),
-          function(x = 1, nrow, ncol = n) .Call("dtpMatrix_getDiag", x, PACKAGE = "Matrix"),
+          function(x = 1, nrow, ncol = n) .Call(dtpMatrix_getDiag, x),
           valueClass = "numeric")
 
 setMethod("norm", signature(x = "dtpMatrix", type = "character"),
 	  function(x, type, ...)
-	  .Call("dtpMatrix_norm", x, type, PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_norm, x, type),
 	  valueClass = "numeric")
 
 setMethod("norm", signature(x = "dtpMatrix", type = "missing"),
 	  function(x, type, ...)
-	  .Call("dtpMatrix_norm", x, "O", PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_norm, x, "O"),
 	  valueClass = "numeric")
 
 setMethod("rcond", signature(x = "dtpMatrix", type = "character"),
 	  function(x, type, ...)
-	  .Call("dtpMatrix_rcond", x, type, PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_rcond, x, type),
 	  valueClass = "numeric")
 
 setMethod("rcond", signature(x = "dtpMatrix", type = "missing"),
 	  function(x, type, ...)
-	  .Call("dtpMatrix_rcond", x, "O", PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_rcond, x, "O"),
 	  valueClass = "numeric")
 
 setMethod("solve", signature(a = "dtpMatrix", b="missing"),
 	  function(a, b, ...)
-	  .Call("dtpMatrix_solve", a, PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_solve, a),
 	  valueClass = "dtpMatrix")
 
 setMethod("solve", signature(a = "dtpMatrix", b="matrix"),
 	  function(a, b, ...)
-	  .Call("dtpMatrix_matrix_solve", a, b, PACKAGE = "Matrix"),
+	  .Call(dtpMatrix_matrix_solve, a, b),
 	  valueClass = "matrix")
 
 setMethod("t", signature(x = "dtpMatrix"),
